import os

from service_driver.project_generator import start_project
from service_driver.__main__ import absolute_import

class TestProjectGenerator:
    def test_start_project(self):
        start_project('new_project')
        assert os.path.isdir(os.path.join('new_project', "api_object"))
        assert os.path.isdir(os.path.join('new_project', "testcase"))



# -*- coding:utf-8 -*-
# @Time     :2023/2/2 10:41 下午
# @Author   :CHNJX
# @File     :project_generator.py
# @Desc     :项目创造器

import sys
from os.path import dirname, exists

sys.path.append(dirname(sys.path[0]))

import click as click
from jinja2 import FileSystemLoader, Environment

import os

group = click.Group()


@click.command('start_project')
@click.option('-n', '--project-name', required=True, help='project name')
def start_project(project_name):
    """
    创建项目
    :param project_name: 项目名称
    :return: None
    """
    if exists(project_name):
        print(f'project {project_name} is already existed')
        return 1
    create_folder(project_name)
    create_folder(os.path.join(project_name, 'testcase'))
    create_folder(os.path.join(project_name, 'api_object'))
    for dir_name in os.listdir(project_name):
        cur_dir = os.path.join(project_name + '/' + dir_name, '__init__.py')
        create_file(cur_dir)
    generate_base_need(project_name)


def create_folder(path):
    os.makedirs(path)
    print(f'create folder {path}')


def create_file(file_path, file_content=""):
    with open(file_path, "w", encoding="utf-8") as f:
        f.write(file_content)
    print(f"created file: {file_path}")


def generate_base_need(project_name):
    template = Template()
    api_object_dir = os.path.join(project_name, 'api_object')
    testcase_dir = os.path.join(project_name, 'testcase')
    _write(template.get_content('base_api.tpl'), os.path.join(api_object_dir, 'base_api.py'))
    _write(template.get_content('api_demo.tpl'), os.path.join(api_object_dir, 'api_demo.py'))
    _write(template.get_content('base_testcase.tpl'), os.path.join(testcase_dir, 'test_base.py'))
    _write(template.get_content('testcase_demo.tpl'), os.path.join(testcase_dir, 'testcase_demo.py'))


def _write(content, file_path):
    dir_ = dirname(file_path)
    if not exists(dir_):
        os.makedirs(dir_)
    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(content)


class Template:
    def __init__(self):
        loader = FileSystemLoader(os.path.join(
            os.path.dirname(__file__), 'templates'))
        self.env = Environment(loader=loader)

    def get_content(self, tpl_name, **kwargs):
        return self.env.get_template(tpl_name).render(**kwargs)


group.add_command(start_project)


def command():
    group.main()


if __name__ == '__main__':
    command()



# -*- coding:utf-8 -*-
# @Time     :2022/6/29 17:12
# @Author   :CHNJX
# @File     :custom_str_utils.py
# @Desc     :字符串的自定义方法
import random
import re
from service_driver.utils.service_logger import Logger


class CustomStrUtils:
    logger = Logger.getLogger("testcase")

    @classmethod
    def get_random_num(cls, formal_str):
        """
        获取随机数占位符的范围
        """
        if "random" not in formal_str:
            cls.logger.info('没有找到占位符')
            return 0

        # 匹配上 random中的范围
        try:
            random_range = re.match(r'.*{random\((.*?)\)}', formal_str, flags=0).group(1)
            return int(random_range)
        except Exception as e:
            cls.logger.error('随机数占位符格式错误')
            return 0
